@@ -25,15 +25,15 @@ use Carp;
 use XML::LibXML;
 use XML::XForms::Generator::Common;
 
-@XML::XForms::Generator::Action::ISA = qw( Exporter XML::LibXML::Element );
+our @ISA = qw( Exporter XML::LibXML::Element );
 
-$XML::XForms::Generator::Action::VERSION = "0.4.0";
+our $VERSION = "0.5.0";
+
+no strict "refs";
 
 ## Loop through the model elements and build convience functions for them.
 foreach my $action ( keys( %XFORMS_ACTION ) )
 {
-	no strict "refs";
-	
 	## Add the name of the action to be exported.
 	Exporter::export_tags( "xforms_action_" . $action );
 	
@@ -52,10 +52,10 @@ foreach my $action ( keys( %XFORMS_ACTION ) )
 		$self->setNamespace( $XFORMS_NSURI, $XFORMS_NSPREFIX, 1 );
 	
 		return( $self );
-	};
-	
-	use strict "refs";
+	};	
 }
+
+use strict "refs";
 				
 ##==================================================================##
 ##  Constructor(s)/Deconstructor(s)                                 ##
@@ -118,10 +118,8 @@ sub DESTROY
 sub _set_attributes
 {
 	my( $self, $attributes ) = @_;
-	
-	my $action = $self->nodeName;
 
-	foreach( @{ $XFORMS_ACTION{ $action } }, "ev:event" )
+	foreach( @{ $XFORMS_ACTION{ $self->nodeName } }, "ev:event" )
 	{
 		## Events are special casses as we can do extra checking on them.
 		if( ( $_ eq "ev:event" ) && ( defined( $$attributes{ "ev:event" } ) ) )
@@ -201,12 +199,13 @@ D. Hageman E<lt>dhageman@dracken.comE<gt>
  XML::XForms::Generator
  XML::XForms::Generator::Control
  XML::XForms::Genertaor::Model
+ XML::XForms::Genertaor::UserInterface
  XML::LibXML
  XML::LibXML::DOM
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2000-2001 D. Hageman (Dracken Technologies).
+Copyright (c) 2002 D. Hageman (Dracken Technologies).
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify 
